#
# spec file for package utsushi
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           utsushi
Version:        1684035837.b296671
Release:        1.1
Summary:        Next Generation Image Acquisition Utilities
License:        GPL-3.0-or-later
URL:            https://gitlab.com/utsushi/utsushi
Source0:        %{name}-%{version}.tar.xz
Source1:        %{name}-rpmlintrc
Patch0:         0001-drivers-avoid-library-version-for-dynamically-loadab.patch
Patch1:         0002-avoid-version-for-dynamic-libs.patch
Patch2:         0003-fix-uint-deprecation.patch
Patch3:         0004-change-sane-version-check.patch
Patch4:         0005-fix-gcc12-werror-address.patch
Patch5:         0006-fix-gcc12-bind2nd-deprecated.patch
BuildRequires:  autoconf
BuildRequires:  autoconf-archive
BuildRequires:  automake
BuildRequires:  boost-devel
BuildRequires:  gcc-c++
BuildRequires:  libboost_filesystem-devel
BuildRequires:  libboost_iostreams-devel
BuildRequires:  libboost_program_options-devel
BuildRequires:  libboost_regex-devel
BuildRequires:  libboost_system-devel
BuildRequires:  libboost_test-devel
BuildRequires:  libboost_thread-devel
BuildRequires:  libtool
BuildRequires:  libtool-ltdl-devel
BuildRequires:  libxslt-tools
BuildRequires:  patchelf
BuildRequires:  pkgconfig
BuildRequires:  sane-backends
BuildRequires:  tesseract-ocr
BuildRequires:  tesseract-ocr-traineddata-orientation_and_script_detection
BuildRequires:  pkgconfig(Magick++)
BuildRequires:  pkgconfig(gtkmm-2.4)
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(libtiff-4)
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(libusb-1.0)
BuildRequires:  pkgconfig(sane-backends)
Provides:       imagescan

%description
This software provides applications to easily turn hard-copy documents and
imagery into formats that are more amenable to computer processing.

Included are a native driver for a number of EPSON scanners and a compatibility
driver to interface with software built around the SANE standard.

This is the community maintained fork, based on imagescan upstream.

%lang_package

%prep
%setup -q
%patch0 -p1
%patch1
%patch2
%patch3
# gcc12 patches are relevant only for TW
%if 0%{?suse_version} > 1500
%patch4
%patch5
%endif
./bootstrap

%build
%configure \
    --with-jpeg \
    --with-tiff \
    --with-gtkmm \
    --with-sane \
    --with-magick \
    --with-magick-pp \
    --enable-sane-config \
    --enable-udev-config \
    --disable-static
%make_build

%check
#make check

%install
%make_install
install -m644 lib/devices.conf %{buildroot}/%{_sysconfdir}/%{name}/%{name}.conf
mkdir -p %{buildroot}/%{_udevrulesdir}
install -m644 drivers/esci/utsushi-esci.rules %{buildroot}/%{_udevrulesdir}/56-utsushi-esci.rules
# Fix issue with "undefined symbol: libcnx_usb_LTX_factory" (https://bugs.archlinux.org/task/63491)
patchelf --add-needed libcnx-usb.so %{buildroot}/%{_libdir}/%{name}/sane/libsane-utsushi.so
# Headers are not needed outside this package
rm -r %{buildroot}/%{_includedir}
# Do not install libtool files
find %{buildroot} -type f -name "*.la" -delete -print
# Remove unwanted link to libtool file
rm %{buildroot}/%{_libdir}/sane/libsane-utsushi.la
%find_lang %{name}

%files
%license COPYING
%doc ChangeLog NEWS README
%{_bindir}/%{name}
%{_libexecdir}/%{name}
%{_libdir}/%{name}
%{_libdir}/sane/libsane-%{name}.*
%{_datadir}/%{name}
%{_udevrulesdir}/56-utsushi-esci.rules
%dir %{_sysconfdir}/%{name}
%config %{_sysconfdir}/%{name}/*.conf
%config %{_sysconfdir}/sane.d/dll.d/%{name}

%files -n %{name}-lang -f %{name}.lang

%changelog
* Tue Jun 20 2023 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Lower requirements in _constraints for armv6/7
* Fri Jun 16 2023 Jan Baier <jbaier@suse.com>
- Update to version 1684035837.b296671:
  * Update Russian translation
* Tue May 24 2022 Jan Baier <jbaier@suse.com>
- Fix compatibility with GCC12:
  - add 0005-fix-gcc12-werror-address.patch
  - add 0006-fix-gcc12-bind2nd-deprecated.patch
* Fri Feb  4 2022 Jan Baier <jbaier@suse.com>
- Update to version 1638580181.839d06a:
  * Trim trailing junk from the SANE version instead
  * Trim trailing junk from the SANE revision
  * CI: Switch from Devuan's beowulf to chimaera
- add 0004-change-sane-version-check.patch as a workaround for #108
* Thu Jun 24 2021 Jan Baier <jbaier@suse.com>
- Update to version 1623553580.85d9379:
  * Add UI strings for color coefficient settings.  Re #103
* Thu May 27 2021 Jan Baier <jbaier@suse.com>
- Update to version 1622031929.7d9d76a:
  * Corrected and completed the Simplified Chinese translation.
* Mon May  3 2021 Jan Baier <jbaier@suse.com>
- fix build for TW
- add 0003-fix-uint-deprecation.patch
* Mon Feb  8 2021 Jan Baier <jbaier@suse.com>
- update to ab706335
  - Document support for the ET-2600
  - Add ET-2720 to sane/utsushi.descy
  - Import version controlled source files for 3.65.0
  - Merge changes from imagescan-3.65.0
  - Add model "names" for newly added models
* Sat Dec 19 2020 Jan Baier <jbaier@suse.com>
- initial upload for TW
- add 0001-drivers-avoid-library-version-for-dynamically-loadab.patch
- add 0002-avoid-version-for-dynamic-libs.patch
